/***************************************************************************
 *            bbthread.h
 *
 *  Thu Jul  7 12:12:08 2005
 *  Copyright  2005  Fabio Marzocca
 *  Email
 ****************************************************************************/

#ifndef BAOBAB_NOTHREAD_H
#define BAOBAB_NOTHREAD_H


	void getDir(gchar *);
	void searchDir(gchar *, gchar* );
	gboolean bb_scan_is_local(gchar *);

#endif /* _BBTHREAD_H */
